@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20241129';
+our $VERSION = '0.20241227';
 
-# Table last modified: 2024-11-29
+# Table last modified: 2024-12-27
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -103,7 +103,7 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6|78)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|6[0-57-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[23578]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|3[2358]|2[1245]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:5[06]|1[015]|2[47]|3[09]|0[235]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
+    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|6[0-57-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[23578]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|3[2358]|2[1245]|0[2367]|4[15]|1[01]|8[038])|5(?:11|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:5[06]|1[015]|2[47]|3[09]|0[235]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
     '101' => '(?:8(?:4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|5[0169]|2[1-59])|6(?:8[28]|0[356]|5[146]|6[57]|2[1246-9]|3[01367]|7[026]|4[235-8]|1[01679])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|3(?:5[013589]|8[38]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258]|6[267])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:1[0-357-9]|2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|3[0-24-68]|6[045]|8[28]|7[2-57]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:8(?:2(?:5[0-2569]|3[0-689]|7[036-8]|0[1-68]|8[2457]|1[0-248]|6[0156]|2[124589]|4[013578])|4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[02457-9]|5[016])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|2[0-25]|0[1-356]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
@@ -131,10 +131,10 @@ our %ZIP_TABLE = (
     '133' => '(?:8(?:5(?:[01]1|8[058]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[5-8]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
     '135' => '(?:8(?:5(?:48|3[0-358]|7[57-9]|2[1-3578]|8[1257]|1[0-478]|5[0-24-9]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[1368]|7[05]|6[023]|3[01]|1[0-28])|1(?:21|50|65|78|1[01458]|0[89]|3[0479]|8[01])|7(?:97|3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
-    '136' => '(?:8(?:5(?:3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|6[07]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[018]|405|908))',
+    '136' => '(?:8(?:5(?:60|3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[018]|405|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|7[1-46]|0[23679]|8[0346]|6[0367]|2[1-3569]|5[1248]|1[1256])|6(?:4[04]|3[0147]|2[1568]|6[013689]|7[025-8]|5[03-68]|0[12]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|(?:45|81)0))',
-    '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|2(?:55|60|1[04]|0[1-6])|4(?:8[78]|1[168]|2[01356])|7(?:1[056]|0[17])|001|924))',
+    '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:8[78]|1[168]|2[0135-8])|2(?:55|60|1[04]|0[1-6])|7(?:1[056]|0[17])|001|924))',
     '142' => '(?:8(?:5(?:[01]1|33|40|5[058])|6(?:11|22|66)|777))',
     '143' => '(?:85(?:70|5[02578]|3[013589]|2[0158]|8[05]|6[0578]|1[13-5]|0[2457-9]|4[014]))',
     '144' => '(?:8(?:5(?:44|66|5[015]|8[018]|7[057]|2[25]|3[1-356]|1[01356]|0[56])|6(?:02|11|5[056]|7[78]|2[1-36]|6[016])))',
@@ -149,7 +149,7 @@ our %ZIP_TABLE = (
     '156' => '(?:8(?:5(?:33|55|88|0[246]|2[02]|1[01])|666))',
     '157' => '(?:85(?:43|50|6[1-35-7]|3[05]|0[18]|2[0-2]|7[0357]|1[01]))',
     '158' => '(?:8(?:5(?:3[1349]|5[0-278]|8[0568]|1[0-48]|6[167]|4[349]|2[0235]|7[578]|0[1-3589])|6(?:40|66|3[0-3]|2[28]|1[05]|0[12])|7[07]1))',
-    '160' => '(?:8(?:3(?:89|7[3-58]|3[01468]|1[1369]|[24][17]|5[1-38]|6[68]|0[1469])|4(?:50|72|1[015]|3[03]|2[0239]|6[136]|4[147]|8[4-9]|0[1-37-9])|5(?:65|1[0-2569]|0[1479]|4[37]|8[0-37-9]|2[0-249]|3[05]|7[157])|0(?:[01]1|70)|6(?:01|80)|8(?:01|12)|910))',
+    '160' => '(?:8(?:4(?:50|72|1[015]|3[03]|2[0239]|6[136]|4[147]|8[4-9]|0[1-37-9])|5(?:65|1[0-2569]|0[1479]|4[37]|8[0-37-9]|2[0-249]|3[05]|7[157])|3(?:21|89|7[3-58]|3[01468]|1[1369]|4[17]|5[1-38]|6[68]|0[1469])|0(?:[01]1|70)|6(?:01|80)|8(?:01|12)|910))',
     '161' => '(?:8(?:5(?:08|11|75|3[19]|6[057]|5[236-8]|4[0156]|2[0-28])|710))',
     '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[0468]|5[04-6]|[36][689]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[058]|7[1368]|8[048]|0[27]|2[12]|1[125])|5(?:75|[16][25]|0[235]|3[05]|8[57]|5[16-8]|4[034])|8(?:30|5[03]|0[1-8]|6[01])|0(?:55|60|2[0-2]|0[15])|7(?:0[17]|1[016-8])|953))',
     '163' => '(?:(?:0(?:5(?:5[378]|7[056]|6[0269])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|2(?:78|6[18])|4(?:56|7[18])|9(?:43|3[68])|7[27]7)|1(?:3(?:50|63|71|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:[28]0|02|3[89]|7[17]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48))))',
@@ -218,7 +218,7 @@ our %ZIP_TABLE = (
     '236' => '(?:8(?:5(?:15|40|0[1-4]|5[05])|6(?:09|5[13]|4[158])))',
     '237' => '(?:85(?:23|55|1[05]))',
     '238' => '(?:(?:8(?:5(?:70|8[058]|3[356]|1[013]|2[02]|6[57]|5[08]|4[01])|6[18]6)|029[28]))',
-    '239' => '(?:8(?:5(?:01|28|60|8[58]|5[08])|68[68]))',
+    '239' => '(?:8(?:5(?:01|28|6[07]|8[58]|5[08])|68[68]))',
     '240' => '(?:(?:8(?:5(?:[02]1|[45]0)|612)|019[235-8]))',
     '241' => '(?:8(?:5(?:25|1[25]|0[12])|606))',
     '242' => '(?:8(?:5(?:[58]5|77|0[27])|6(?:01|10)))',
@@ -240,7 +240,7 @@ our %ZIP_TABLE = (
     '258' => '(?:(?:85(?:11|77|85|3[38]|0[16])|0195))',
     '259' => '(?:(?:0(?:1(?:9[2-467]|8[01])|39[2356])|1(?:1(?:8[5-8]|9[236-8])|292)))',
     '260' => '(?:8(?:6(?:0[13467]|1[0-389]|8[1258]|2[0-24-79]|5[46]|4[2578]|6[0-35-8]|7[0-357]|3[135-7])|5(?:40|7[0257]|5[1257-9]|8[0568]|1[0-35-8]|0[1-35-9]|3[4-68]|6[0-467]|2[13478])|7(?:1[02357]|0[137]|3[34]|2[02])))',
-    '261' => '(?:8(?:5(?:1[0-35]|6[0168]|3[0359]|7[57]|5[0248]|0[1-478]|8[125-8]|4[145]|2[0-28])|6(?:86|0[1-39])|733))',
+    '261' => '(?:8(?:5(?:1[0-35]|6[0168]|3[0359]|8[0-25-8]|7[57]|5[0248]|0[1-478]|4[145]|2[0-28])|6(?:86|0[1-39])|733))',
     '262' => '(?:8(?:5(?:0[26]|1[0-24])|733))',
     '263' => '(?:8(?:5(?:[12]2|33|77|6[06]|8[58]|5[05]|0[56])|733))',
     '264' => '(?:8(?:5(?:[135]0|8[25]|0[15])|6(?:04|46)|733))',
@@ -324,7 +324,7 @@ our %ZIP_TABLE = (
     '348' => '(?:8(?:5(?:[258]5|30|1[23]|0[1-35-8]|4[09])|601))',
     '349' => '(?:(?:0(?:19[23568]|29[2-6])|1(?:19[23]|292)))',
     '350' => '(?:(?:1(?:1(?:9[24-8]|8[1-358])|3(?:8[035689]|9[2568])|29[25-8])|0(?:2(?:9[25]|8[02-9])|39[2-6]|19[2357]|49[3-6])|8(?:5(?:[03]1|8[58]|5[05]|1[01])|6(?:01|66))|22(?:8[0-278]|9[25])))',
-    '351' => '(?:(?:8(?:5(?:[26]0|55|0[138]|1[01]|8[56])|601)|01(?:88|9[2-46-8])))',
+    '351' => '(?:(?:8(?:5(?:[26]0|55|0[138]|1[01]|8[56])|601)|01(?:9[2-46-8]|8[08])))',
     '352' => '(?:8(?:5(?:01|10|23|49|8[89]|7[27]|5[58])|6(?:23|66)))',
     '353' => '(?:85(?:01|55))',
     '354' => '(?:85(?:33|77|[68][05]|5[58]|1[01]|0[145]))',
@@ -472,7 +472,7 @@ our %ZIP_TABLE = (
     '500' => '(?:8(?:6(?:[14][0568]|5[057]|7[0-26-8]|2[0-25]|0[1-357]|8[0-25-79]|3[05-9]|6[06-8])|5(?:88|6[0-25-7]|0[1-578]|1[0358]|4[0145]|2[1-5]|3[035]|7[017]|5[024-8])|7(?:65|4[0-38]|2[1-357-9]|1[015-8]|3[0-479]|5[0-5]|0[1-378])))',
     '501' => '(?:(?:0(?:69[2-8]|29[2-6]|49[25-8]|59[26]|79[78]|[13]92)|3(?:99[2-48]|29[356]|39[235]|89[2-4]|792)|6(?:1(?:9[2-8]|8[01])|29[235])|1(?:19[2-68]|39[23]|592)|4(?:29[278]|19[23]|59[25])|2(?:[1258]92|69[578])|5(?:[146]92|393)))',
     '502' => '(?:8(?:5(?:[12]1|58|67|85|0[13])|792))',
-    '503' => '(?:(?:8(?:5(?:5[02-46-9]|2[0-3]|[01][1-9]|7[01]|6[0-24-9])|60[134])|2(?:39[2-7]|49[2-5]|19[23])|0(?:19[258]|29[25]|[46]95|392)|1(?:39[2-6]|59[235]|696)))',
+    '503' => '(?:(?:8(?:5(?:5[02-46-9]|2[0-3]|[01][1-9]|7[01]|6[0-24-9])|60[134])|2(?:39[2-7]|49[2-5]|19[23])|0(?:19[28]|29[25]|[46]95|392)|1(?:39[2-6]|59[235]|696)))',
     '504' => '(?:8(?:5(?:[48]5|11|0[14]|5[15])|7(?:10|0[12])|6(?:01|42)))',
     '505' => '(?:(?:8(?:5(?:10|0[1358])|60[36])|0392))',
     '506' => '(?:(?:8(?:6(?:66|78|90|0[13]|8[6-8])|5(?:77|85|0[26]|5[05]))|1(?:49[23568]|19[56]|392)|019[24]|2192))',
@@ -485,7 +485,7 @@ our %ZIP_TABLE = (
     '513' => '(?:8(?:6(?:[57]0|01|8[06]|3[0-3]|6[016])|5(?:[1-3]0|0[15])|701))',
     '514' => '(?:(?:8(?:5(?:4[0356]|3[0-38]|1[0-58]|5[023578]|8[568]|7[0178]|2[0-2468]|0[1-3578]|6[06-8])|6(?:[01]1|86|6[6-8]|3[35]))|2(?:39[23568]|29[2-4]|192)|1(?:29[2-7]|19[235])|039[235-8]))',
     '515' => '(?:(?:8(?:5(?:77|3[03]|2[25]|8[568]|6[67]|1[0135]|5[0578]|0[1359])|688)|2(?:69[23]|592)|059[2568]))',
-    '516' => '(?:(?:8(?:5(?:20|77|3[03]|5[0-58]|8[018]|4[3-9]|6[67]|1[12568]|0[1-35])|6(?:86|0[12]))|1(?:19[2568]|492)|019[2-48]|2195))',
+    '516' => '(?:(?:8(?:5(?:20|77|3[03]|5[0-58]|4[3-9]|6[67]|1[12568]|8[18]|0[1-35])|6(?:86|0[12]))|1(?:19[2568]|492)|019[2-48]|2195))',
     '517' => '(?:(?:0(?:59[235]|292|494)|85(?:01|1[17])))',
     '518' => '(?:(?:0(?:29[2-68]|49[2-6]|192)|85(?:01|18|33)))',
     '519' => '(?:(?:0(?:19[3-8]|49[2357]|59[2-5]|292|393|696)|3(?:69[2-6]|[24]92)|2(?:59[23]|[17]92)|439[2-6]|529[23]|1192))',
@@ -499,7 +499,7 @@ our %ZIP_TABLE = (
     '527' => '(?:(?:8(?:5(?:[27]7|42|0[158]|8[058]|6[67]|1[12]|5[0458])|687)|0195))',
     '528' => '(?:8(?:5(?:[58]5|0[12]|1[01])|666))',
     '529' => '(?:(?:1(?:3(?:93|8[0-368])|59[2578]|49[235]|69[28]|195|892)|0(?:49[238]|[27]92)))',
-    '530' => '(?:(?:8(?:2(?:4[015]|2[1246-8]|3[0249]|5[0-256]|6[0236]|1[0-8]|7[08]|0[1-79]|8[0-378])|5(?:44|2[1-3]|7[3-578]|6[05-8]|0[146]|3[15]|1[1-37]|8[023568]|5[0-3568])|3(?:3[348]|0[148]|8[389]|4[16]|2[1-47]|1[08]|5[035])|4(?:75|80|1[015]|0[128]|4[18])|6(?:60|1[018]|8[089]|0[1256])|79[136-8])|6070))',
+    '530' => '(?:(?:8(?:2(?:4[015]|2[1246-8]|3[0249]|5[0-256]|6[0236]|1[0-8]|7[08]|0[1-79]|8[0-378])|5(?:44|2[1-3]|7[3-578]|6[05-8]|0[1467]|3[15]|1[1-37]|8[023568]|5[0-3568])|3(?:3[348]|0[148]|8[389]|4[16]|2[1-47]|1[08]|5[035])|4(?:75|80|1[015]|0[128]|4[18])|6(?:60|1[018]|8[089]|0[1256])|79[136-8])|6070))',
     '531' => '(?:(?:8(?:5(?:[67]7|26|88|0[1-3]|1[019]|5[58])|787)|6053))',
     '532' => '(?:8(?:5(?:35|60|88|2[045]|1[1245]|5[58]|0[1578])|680))',
     '533' => '(?:8(?:5(?:33|85|5[58]|0[12])|651))',
@@ -539,7 +539,7 @@ our %ZIP_TABLE = (
     '569' => '(?:(?:8(?:5(?:33|49|0[135]|5[158]|2[02]|8[58]|7[0157]|6[679]|1[0-2])|6(?:60|86))|1(?:19[2-7]|09[24-68])))',
     '570' => '(?:8(?:5(?:39|40|0[167]|[58][58]|1[15])|6(?:34|66)|787))',
     '571' => '(?:8(?:5(?:[45]5|33|67|71|8[05]|0[2-47])|6(?:[24]0|33|86)))',
-    '572' => '(?:85(?:40|8[01589]|0[158]|2[28]|3[013]|7[02]|5[0158]|6[67]|1[01]))',
+    '572' => '(?:85(?:4[04]|8[01589]|0[158]|2[28]|3[013]|7[02]|5[0158]|6[67]|1[01]))',
     '573' => '(?:(?:8(?:5(?:34|56|67|73|88|0[58]|1[0-2])|6(?:54|66))|10(?:[34]0|1[03]|0[1478])|019[356]))',
     '574' => '(?:85(?:[58]5|01|3[0-4]))',
     '575' => '(?:85(?:[01]1|30|[58][58]))',
@@ -576,7 +576,7 @@ our %ZIP_TABLE = (
     '607' => '(?:85[017]1)',
     '610' => '(?:(?:0(?:3(?:80|9[3-7])|19[256]|28[179])|119[258]))',
     '611' => '(?:8(?:5(?:[02]1|55|8[58])|660))',
-    '612' => '(?:8(?:5(?:01|22|77|85|3[03]|5[058]|1[15])|6(?:02|60|77|86)))',
+    '612' => '(?:8(?:5(?:01|22|77|85|3[03]|1[158]|5[058])|6(?:02|60|77|86)))',
     '613' => '(?:8585)',
     '614' => '(?:85(?:[01]1|88))',
     '615' => '(?:8(?:5(?:[34]0|01|77|85|2[02]|5[58]|1[01])|6[68]6))',
@@ -758,7 +758,7 @@ our %ZIP_TABLE = (
     '797' => '(?:(?:(?:02|1[257])92|85[01]1))',
     '798' => '(?:(?:8(?:6(?:01|1[14])|51[01])|4(?:19[2-7]|292|495)|1(?:39[2357]|192)|3(?:39[23]|792)|2192))',
     '799' => '(?:(?:1(?:5(?:8[128]|9[2-68])|39[2-5]|198|692)|2(?:29[2-4]|49[236]|19[25]|39[23]|69[26])|0(?:19[2-7]|49[235-8])|3(?:19[2-68]|79[23]|292)))',
-    '800' => '(?:(?:8(?:5(?:10|85|5[05])|6(?:11|86|0[13]))|0(?:2(?:9[346-8]|8[12568])|39[2-6])))',
+    '800' => '(?:(?:0(?:2(?:9[2-46-8]|8[12568])|39[2-6])|8(?:5(?:10|85|5[05])|6(?:11|86|0[13]))))',
     '801' => '(?:8(?:5(?:85|5[05]|0[237]|1[01])|601))',
     '802' => '(?:8(?:5(?:33|8[015]|1[0-257]|0[1278]|5[058]|2[124]|6[0167]|4[035]|7[017])|6(?:42|51|77|86|0[14])|701))',
     '803' => '(?:8(?:5(?:20|43|3[0-35]|1[0-37]|6[17]|5[058]|8[068]|0[1458])|6(?:02|30|86|6[06])|787))',
@@ -850,14 +850,14 @@ our %ZIP_TABLE = (
     '889' => '(?:(?:1(?:49[2358]|69[2356]|99[4-7]|[18]92|795)|0(?:69[235-8]|59[25]|[13]92)|(?:4[2-5]|2[14])92))',
     '890' => '(?:8(?:5(?:6[05-7]|3[0-35]|1[0-257]|0[1-9]|8[015689]|4[013-5]|2[0-57]|5[0258]|7[014578])|6(?:[68]6|10|0[134])|7(?:60|9[48])))',
     '891' => '(?:(?:0(?:1(?:8[02-46-9]|9[2-8])|49[378]|[67]92)|3(?:19[2-68]|69[23]|79[23])|1(?:39[2-5]|[15]92)|9(?:29[2-6]|192)|(?:[46]2|7[16])92|2(?:39[36]|192)|8293))',
-    '892' => '(?:8(?:5(?:20|4[03]|1[25]|8[568]|5[058]|6[367]|3[01359]|0[125])|6(?:11|26|33|50|77|88|0[13])))',
+    '892' => '(?:8(?:5(?:20|4[03]|1[25]|8[568]|5[058]|6[367]|3[01359]|0[125])|6(?:11|33|50|77|88|2[69]|0[13])))',
     '893' => '(?:(?:1(?:19[28]|69[23]|298)|8(?:5(?:10|0[12])|611)|(?:02|2[34])92))',
     '894' => '(?:(?:8(?:5(?:11|55|67|0[17]|8[58])|6(?:01|55|77|88))|(?:3[13]|1[25])92|0(?:192|595)))',
     '895' => '(?:(?:8(?:5(?:40|55|88|0[1-6]|1[59])|6(?:01|50|86))|1(?:29[2356]|492|595)|229[28]|0292))',
     '896' => '(?:(?:1(?:[13]92|696)|86(?:01|86)))',
     '897' => '(?:(?:039[23]|8501))',
     '898' => '(?:8501)',
-    '899' => '(?:(?:5(?:19[235]|29[2-4]|69[348]|49[25]|392)|6(?:49[2-5]|19[23]|29[23]|592)|(?:3[14]|7[146]|8[16])92|2(?:59[2-6]|[127]92)|4(?:39[2-6]|[12]92)|0(?:29[23578]|492)|1(?:395|498|696)))',
+    '899' => '(?:(?:5(?:19[235]|29[2-4]|69[348]|49[25]|392)|6(?:49[2-5]|19[23]|29[23]|592)|2(?:59[2-6]|[127]92)|4(?:39[2-6]|[12]92)|(?:3[14]|7[146])92|0(?:29[23578]|492)|1(?:395|498|696)|8(?:19[23]|692)))',
     '900' => '(?:8(?:5(?:5\d|2[02457]|8[1568]|4[03-578]|1[02-467]|6[07]|3[013-5]|0[13-5]|7[01578])|6(?:10|66|78|0[1-589]|5[014]|8[68])|7(?:[01]1|35|9[4-7])))',
     '901' => '(?:(?:2(?:5(?:40|88|97|0[1267]|6[0679]|1[0-25]|5[0-35-9]|2[0156]|3[01])|6(?:86|0[127]|1[01])|7(?:01|10|33)|49[2356]|39[235])|0(?:19[2-467]|49[2-6]|29[245]|39[23]|592)|1(?:19[2356]|39[23]|49[25]|292|595)|3(?:[679]92|19[23]|59[25]|496|895)))',
     '902' => '(?:85(?:21|1[0-3]|8[58]|5[05]|7[01]))',
@@ -879,7 +879,7 @@ our %ZIP_TABLE = (
     '920' => '(?:(?:8(?:5(?:2[0-25]|4[013-5]|3[0135-9]|1[0-35-8]|7[0357]|0[1-57-9]|5[0-8]|[68][035-8])|6(?:2[0-358]|8[1568]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|4[0-248]|6[0156]|1[0-69])|7(?:[67]7|30|9[3-7]|0[17]|2[189]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
     '921' => '(?:8(?:5(?:6[0-245]|5[025]|1[0-2578]|3[0-269]|0[15-8]|2[035-79]|8[0-589]|4[1468]|7[1-79])|6(?:01|16|50|3[079]|2[01])|798))',
     '922' => '(?:(?:8(?:5(?:[37]0|01|66|2[25]|8[58]|5[05]|1[01])|6(?:09|11|22|50|78|86))|0(?:29[3-578]|19[23]|49[57]|595)))',
-    '923' => '(?:(?:8(?:5(?:6[05-7]|5[0-257]|8[0168]|7[058]|3[013]|2[0158]|0[1-357]|4[14-6]|1[01])|6(?:50|66|2[06]|4[02-46]|0[13569]|1[0156]|8[68]|3[039]))|1(?:29[2-7]|198)|039[238]))',
+    '923' => '(?:(?:8(?:5(?:6[05-7]|5[0-257]|4[14-689]|8[0168]|7[058]|3[013]|2[0158]|0[1-357]|1[01])|6(?:50|66|2[06]|4[02-46]|0[13569]|1[0156]|8[68]|3[039]))|1(?:29[2-7]|198)|039[238]))',
     '924' => '(?:8(?:5(?:22|33|44|77|6[06]|8[058]|5[58]|1[01])|68[68]|777))',
     '925' => '(?:(?:8(?:5(?:11|30|85|6[67]|0[12568]|5[05]|2[15])|6(?:[12]0|09|88))|0(?:19[38]|392|498|697)))',
     '926' => '(?:(?:8(?:5(?:[013]1|20|66|4[015]|8[568]|5[058])|6(?:[68]6|42|50|1[01]|0[1-359]))|0(?:29[23]|192)))',
